import React, { useRef, useState } from 'react';
import { Button } from '../buttons';
import { Delete, ArrowDropDown } from '@mui/icons-material';
import { EntityPill } from '@graphpolaris/shared/lib/components/pills/Pill';

export type PillDropdownProps = {
  dropdownNodes: string[];
  onSelectOption: (option: string) => void;
};

export const PillDropdown: React.FC<PillDropdownProps> = ({ dropdownNodes, onSelectOption }) => {
  const [isCollapsed, setIsCollapsed] = useState(true);
  const [initialNamePill, setInitialNamePill] = useState('Choose an entity');

  const handleButtonClick = () => {
    setIsCollapsed(!isCollapsed);
  };

  const handleOptionClick = (option: string) => {
    console.log(option);
    //onSelectOption(option);
    setInitialNamePill(option);
    setIsCollapsed(true);
  };

  return (
    <div className="flex flex-col">
      <div className="flex">
        <EntityPill
          title={
            <div className="flex flex-row items-center justify-between">
              <span>{initialNamePill}</span>
              <Button type="secondary" variant="ghost" size="xs" iconComponent={<ArrowDropDown />} onClick={handleButtonClick} />
            </div>
          }
        />
      </div>
      {!isCollapsed && (
        <div className="flex flex-col my-2">
          {dropdownNodes.map((node, index) => (
            <div className="my-0.5 cursor-pointer" onClick={() => handleOptionClick(node)}>
              <EntityPill key={'entity_' + index} title={node} />
            </div>
          ))}
        </div>
      )}
    </div>
  );
};

export default PillDropdown;
